@@ -3,15 +3,24 @@ from codecs import getincrementalencoder
 from HTMLParser import HTMLParser
 from random import choice
 
+from searx.version import VERSION_STRING
+from searx import settings
+
 import cStringIO
 import csv
 import os
 import re
 
-ua_versions = ('26.0', '27.0', '28.0')
+ua_versions = ('29.0',
+               '30.0',
+               '31.0',
+               '32.0',
+               '33.0')
+
 ua_os = ('Windows NT 6.3; WOW64',
          'X11; Linux x86_64',
          'X11; Linux x86')
+
 ua = "Mozilla/5.0 ({os}) Gecko/20100101 Firefox/{version}"
 
 
@@ -21,7 +30,8 @@ def gen_useragent():
 
 
 def searx_useragent():
-    return 'searx'
+    return 'searx/{searx_version} {suffix}'.format(searx_version=VERSION_STRING,
+                                          suffix=settings['server'].get('useragent_suffix', ''))
 
 
 def highlight_content(content, query):
